@@ -19,13 +19,13 @@ else:
 __all__ = (
     "AssumedRoleUserTypeDef",
     "CredentialsTypeDef",
+    "FederatedUserTypeDef",
     "AssumeRoleResponseTypeDef",
     "AssumeRoleWithSAMLResponseTypeDef",
     "AssumeRoleWithWebIdentityResponseTypeDef",
     "DecodeAuthorizationMessageResponseTypeDef",
     "GetAccessKeyInfoResponseTypeDef",
     "GetCallerIdentityResponseTypeDef",
-    "FederatedUserTypeDef",
     "GetFederationTokenResponseTypeDef",
     "GetSessionTokenResponseTypeDef",
     "PolicyDescriptorTypeTypeDef",
@@ -39,11 +39,13 @@ CredentialsTypeDef = TypedDict(
     {"AccessKeyId": str, "SecretAccessKey": str, "SessionToken": str, "Expiration": datetime},
 )
 
+FederatedUserTypeDef = TypedDict("FederatedUserTypeDef", {"FederatedUserId": str, "Arn": str})
+
 AssumeRoleResponseTypeDef = TypedDict(
     "AssumeRoleResponseTypeDef",
     {
-        "Credentials": CredentialsTypeDef,
-        "AssumedRoleUser": AssumedRoleUserTypeDef,
+        "Credentials": "CredentialsTypeDef",
+        "AssumedRoleUser": "AssumedRoleUserTypeDef",
         "PackedPolicySize": int,
     },
     total=False,
@@ -52,8 +54,8 @@ AssumeRoleResponseTypeDef = TypedDict(
 AssumeRoleWithSAMLResponseTypeDef = TypedDict(
     "AssumeRoleWithSAMLResponseTypeDef",
     {
-        "Credentials": CredentialsTypeDef,
-        "AssumedRoleUser": AssumedRoleUserTypeDef,
+        "Credentials": "CredentialsTypeDef",
+        "AssumedRoleUser": "AssumedRoleUserTypeDef",
         "PackedPolicySize": int,
         "Subject": str,
         "SubjectType": str,
@@ -67,9 +69,9 @@ AssumeRoleWithSAMLResponseTypeDef = TypedDict(
 AssumeRoleWithWebIdentityResponseTypeDef = TypedDict(
     "AssumeRoleWithWebIdentityResponseTypeDef",
     {
-        "Credentials": CredentialsTypeDef,
+        "Credentials": "CredentialsTypeDef",
         "SubjectFromWebIdentityToken": str,
-        "AssumedRoleUser": AssumedRoleUserTypeDef,
+        "AssumedRoleUser": "AssumedRoleUserTypeDef",
         "PackedPolicySize": int,
         "Provider": str,
         "Audience": str,
@@ -89,20 +91,18 @@ GetCallerIdentityResponseTypeDef = TypedDict(
     "GetCallerIdentityResponseTypeDef", {"UserId": str, "Account": str, "Arn": str}, total=False
 )
 
-FederatedUserTypeDef = TypedDict("FederatedUserTypeDef", {"FederatedUserId": str, "Arn": str})
-
 GetFederationTokenResponseTypeDef = TypedDict(
     "GetFederationTokenResponseTypeDef",
     {
-        "Credentials": CredentialsTypeDef,
-        "FederatedUser": FederatedUserTypeDef,
+        "Credentials": "CredentialsTypeDef",
+        "FederatedUser": "FederatedUserTypeDef",
         "PackedPolicySize": int,
     },
     total=False,
 )
 
 GetSessionTokenResponseTypeDef = TypedDict(
-    "GetSessionTokenResponseTypeDef", {"Credentials": CredentialsTypeDef}, total=False
+    "GetSessionTokenResponseTypeDef", {"Credentials": "CredentialsTypeDef"}, total=False
 )
 
 PolicyDescriptorTypeTypeDef = TypedDict("PolicyDescriptorTypeTypeDef", {"arn": str}, total=False)
